@@ -489,18 +489,20 @@ print( "w: ", w)
 # Test wrapper for:
 #    void py_NonmodularityIndexMob(double* Mob, double* out_w, struct fm_env* env)
 v =[0.0, 0.3, 0.5, -0.2, 0.4, 0.1, -0.2, 0.1]
-w = pyw.NonmodularityIndexMob(Mob, env)
+w = pyw.NonmodularityIndexMob(v, env)
 print( "v: ", v)
 print( "w: ", w)
 
 # Test wrapper for:
 #    void py_NonmodularityIndexMobkadditive(double* Mob, double* out_w, int k,  struct fm_env* env)
-v =[0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
 k = 2
-w = pyw.NonmodularityIndexMobkadditive(Mob, k, env)
-print( "v: ", v)
+Mob =[0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
+pnm = pyw.NonmodularityIndexMobkadditive(Mob, k, env)
 print( "k: ", k)
-print( "w: ", w)
+print( "Mob: ", Mob)
+print( "nonmodularity indices: ", pnm)
+
+sys.exit()
 
 # Test wrapper for:
 #    int py_IsMeasureBalanced(double* v, struct fm_env* env)
